@@ -5,30 +5,34 @@
 
 package kotlin
 
-@PublishedApi
-internal fun throwUninitializedPropertyAccessException(name: String): Nothing =
-    throw UninitializedPropertyAccessException("lateinit property $name has not been initialized")
+import kotlin.internal.UsedFromCompilerGeneratedCode
 
-@PublishedApi
+@UsedFromCompilerGeneratedCode
 internal fun throwKotlinNothingValueException(): Nothing =
     throw KotlinNothingValueException()
 
+@UsedFromCompilerGeneratedCode
 internal fun noWhenBranchMatchedException(): Nothing = throw NoWhenBranchMatchedException()
 
+@UsedFromCompilerGeneratedCode
 internal fun THROW_ISE(): Nothing {
     throw IllegalStateException()
 }
 
+@UsedFromCompilerGeneratedCode
 internal fun THROW_CCE(): Nothing {
     throw ClassCastException()
 }
 
+@UsedFromCompilerGeneratedCode
 internal fun THROW_NPE(): Nothing {
     throw NullPointerException()
 }
 
+@UsedFromCompilerGeneratedCode
 internal fun THROW_IAE(msg: String): Nothing {
     throw IllegalArgumentException(msg)
 }
 
-internal fun <T:Any> ensureNotNull(v: T?): T = if (v == null) THROW_NPE() else v
\ No newline at end of file
+@UsedFromCompilerGeneratedCode
+internal fun <T:Any> ensureNotNull(v: T?): T = if (v == null) THROW_NPE() else v
